"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.notify = exports.DashboardPages = exports.Channel = exports.Role = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixPingNotificationsV1PublicNotification = __importStar(require("./ping-notifications-v1-public-notification-notifications.http.js"));
var Role;
(function (Role) {
    /** All site contributors. */
    Role["All_Contributors"] = "All_Contributors";
    /** Site owner only. */
    Role["Owner"] = "Owner";
})(Role || (exports.Role = Role = {}));
var Channel;
(function (Channel) {
    /** No default channel. */
    Channel["Undefined"] = "Undefined";
    /** Site dashboard. */
    Channel["Dashboard"] = "Dashboard";
    /** [Wix Owner](https://www.wix.com/mobile/wix-app) mobile app. */
    Channel["Mobile"] = "Mobile";
    /** Active browser. Supported on Chrome and Safari only. */
    Channel["Browser"] = "Browser";
})(Channel || (exports.Channel = Channel = {}));
var DashboardPages;
(function (DashboardPages) {
    DashboardPages["Undefined_Page"] = "Undefined_Page";
    /** Site dashboard home. */
    DashboardPages["Home"] = "Home";
})(DashboardPages || (exports.DashboardPages = DashboardPages = {}));
/**
 * Sends a notification.
 *
 *
 * The `notify()` function sends a [notification](https://support.wix.com/en/article/about-your-dashboard-notifications) to the specified recipients on the specified channels.
 *
 * List the the channels for the notification in the `channels` parameter .
 *
 * List the recipients for the notification in the `toContacts`, `toSiteContributors`, and `toTopicsSubscribers` parameters.
 * @public
 * @documentationMaturity preview
 * @requiredField body
 * @requiredField channels
 * @param options - Notification options.
 * @param body - Body of the notification. This contains the main content of the notification.
 * @param channels - Channel through which users receive the notification.
 * - `"Mobile"`: Sends the notification to the Wix App.
 * - `"Dashboard"`: Sends the notification to the collaborator's Wix Dashboard.
 * - `"Browser"`: Sends the notification to the collaborator's browser.
 * @returns Fulfilled when the send notification request is received.
 * @fqn com.wixpress.ping.hub.api.PublicNotificationsService.Notify
 */
async function notify(body, channels, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[3];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        body: body,
        channels: channels,
        toSiteContributors: options?.toSiteContributors,
        toContacts: options?.toContacts,
        title: options?.title,
        action: options?.action,
        targetUrl: options?.targetUrl,
        targetDashboardPage: options?.targetDashboardPage,
    });
    const reqOpts = ambassadorWixPingNotificationsV1PublicNotification.notify(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                body: '$[0]',
                channels: '$[1]',
                toSiteContributors: '$[2].toSiteContributors',
                toContacts: '$[2].toContacts',
                title: '$[2].title',
                action: '$[2].action',
                targetUrl: '$[2].targetUrl',
                targetDashboardPage: '$[2].targetDashboardPage',
            },
            singleArgumentUnchanged: false,
        }, ['body', 'channels', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.notify = notify;
//# sourceMappingURL=ping-notifications-v1-public-notification-notifications.universal.js.map