import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixPingNotificationsV1PublicNotification from './ping-notifications-v1-public-notification-notifications.http.js';
export var Role;
(function (Role) {
    /** All site contributors. */
    Role["All_Contributors"] = "All_Contributors";
    /** Site owner only. */
    Role["Owner"] = "Owner";
})(Role || (Role = {}));
export var Channel;
(function (Channel) {
    /** No default channel. */
    Channel["Undefined"] = "Undefined";
    /** Site dashboard. */
    Channel["Dashboard"] = "Dashboard";
    /** [Wix Owner](https://www.wix.com/mobile/wix-app) mobile app. */
    Channel["Mobile"] = "Mobile";
    /** Active browser. Supported on Chrome and Safari only. */
    Channel["Browser"] = "Browser";
})(Channel || (Channel = {}));
export var DashboardPages;
(function (DashboardPages) {
    DashboardPages["Undefined_Page"] = "Undefined_Page";
    /** Site dashboard home. */
    DashboardPages["Home"] = "Home";
})(DashboardPages || (DashboardPages = {}));
/**
 * Sends a notification.
 *
 *
 * The `notify()` function sends a [notification](https://support.wix.com/en/article/about-your-dashboard-notifications) to the specified recipients on the specified channels.
 *
 * List the the channels for the notification in the `channels` parameter .
 *
 * List the recipients for the notification in the `toContacts`, `toSiteContributors`, and `toTopicsSubscribers` parameters.
 * @public
 * @documentationMaturity preview
 * @requiredField body
 * @requiredField channels
 * @param options - Notification options.
 * @param body - Body of the notification. This contains the main content of the notification.
 * @param channels - Channel through which users receive the notification.
 * - `"Mobile"`: Sends the notification to the Wix App.
 * - `"Dashboard"`: Sends the notification to the collaborator's Wix Dashboard.
 * - `"Browser"`: Sends the notification to the collaborator's browser.
 * @returns Fulfilled when the send notification request is received.
 * @fqn com.wixpress.ping.hub.api.PublicNotificationsService.Notify
 */
export async function notify(body, channels, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[3];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        body: body,
        channels: channels,
        toSiteContributors: options?.toSiteContributors,
        toContacts: options?.toContacts,
        title: options?.title,
        action: options?.action,
        targetUrl: options?.targetUrl,
        targetDashboardPage: options?.targetDashboardPage,
    });
    const reqOpts = ambassadorWixPingNotificationsV1PublicNotification.notify(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                body: '$[0]',
                channels: '$[1]',
                toSiteContributors: '$[2].toSiteContributors',
                toContacts: '$[2].toContacts',
                title: '$[2].title',
                action: '$[2].action',
                targetUrl: '$[2].targetUrl',
                targetDashboardPage: '$[2].targetDashboardPage',
            },
            singleArgumentUnchanged: false,
        }, ['body', 'channels', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=ping-notifications-v1-public-notification-notifications.universal.js.map